the netlogo link jar is dependent on the specific netlogo version, and needs to
be created by having the associated netlogo jar for the specific version on the
build path.

pynetlogo uses the jar file suitable for the specified/identified version of
netlogo.


jar cfv netlogolink63.jar *